==> segatex-8.500.tar.gz: segatex-8.500/src/sepolicygenerate.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEPOLICYGENERATE_H
#define SEPOLICYGENERATE_H

#include <qdialog.h>
#include <qlayout.h>
#include <qdir.h> 
#include <qfile.h> 
#include <qregexp.h> 
#include <qlabel.h> 
#include <q3textedit.h>
#include <qcheckbox.h>
//Added by qt3to4:
#include <QHBoxLayout>
#include <QVBoxLayout>

//#include "sepolicygenerate_process.h" 

class Q3TextEdit;
class QLineEdit;
class QPushButton;
class QProcess;

class SepolicyGenerate: public QDialog 
{
	Q_OBJECT
public:
	SepolicyGenerate(QWidget *parent = 0, const char *name = 0);
public slots:
signals:
protected:
private slots:
	void policygeneration_base_process();
	void policygeneration_button_clicked();
	void policygeneration_button_clicked_ok();
	void processExited();
	void policygeneration_button_clicked_process(QString textEdit1_str, QString textEdit2_str);
	void readFromOutputFile();
public:
private:
	QPushButton *policygenerationButton;
	QPushButton *closeButton;
	Q3TextEdit *textEdit1;

	QVBoxLayout *mainLayout;
	QVBoxLayout *upperLayout;
	QVBoxLayout *underLayout;
	QVBoxLayout *leftLayout;
	QHBoxLayout *rightLayout;
	QVBoxLayout *middleLayout;
	QHBoxLayout *footLayout;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;
        QString semanageEditLineEdit_str;
        QString semanageEditLineEdit2_str;
        QString semanageEditLineEdit3_str;

        QStringList::Iterator it_d;
        QStringList files;

        QString radiobutton_obj_str;
        QLabel *semanageEditLabel;
        QLabel *semanageEditLabel2;
        QLineEdit *semanageEditLineEdit;
        QLineEdit *semanageEditLineEdit2;
        QString policy_module_name;
        QString semanageEditLineEdit_str_pp;

        QProcess *process;
};

#endif

==> segatex-8.630.tar.gz: segatex-8.630/src/sepolicygenerate.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEPOLICYGENERATE_H
#define SEPOLICYGENERATE_H

#include <QDialog>
#include <QLayout>
#include <QDir> 
#include <QFile> 
#include <QRegExp> 
#include <QLabel> 
#include <QTextEdit>
#include <QCheckBox>
#include <QHBoxLayout>
#include <QVBoxLayout>

//#include "sepolicygenerate_process.h" 

class QTextEdit;
class QLineEdit;
class QPushButton;
class QProcess;

class SepolicyGenerate: public QDialog 
{
	Q_OBJECT
public:
	SepolicyGenerate(QWidget *parent = 0, const char *name = 0);
public slots:
signals:
protected:
private slots:
	void policygeneration_base_process();
	void policygeneration_button_clicked();
	void policygeneration_button_clicked_ok();
	void processExited();
	void policygeneration_button_clicked_process(QString textEdit1_str, QString textEdit2_str);
	void readFromOutputFile();
public:
private:
	QPushButton *policygenerationButton;
	QPushButton *closeButton;
	QTextEdit *textEdit1;

	QVBoxLayout *mainLayout;
	QVBoxLayout *upperLayout;
	QVBoxLayout *underLayout;
	QVBoxLayout *leftLayout;
	QHBoxLayout *rightLayout;
	QVBoxLayout *middleLayout;
	QHBoxLayout *footLayout;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;
        QString semanageEditLineEdit_str;
        QString semanageEditLineEdit2_str;
        QString semanageEditLineEdit3_str;

        QStringList::Iterator it_d;
        QStringList files;

        QString radiobutton_obj_str;
        QLabel *semanageEditLabel;
        QLabel *semanageEditLabel2;
        QLineEdit *semanageEditLineEdit;
        QLineEdit *semanageEditLineEdit2;
        QString policy_module_name;
        QString semanageEditLineEdit_str_pp;

        QProcess *process;
};

#endif
